--- setup.py.orig	2021-07-06 11:19:31 UTC
+++ setup.py
@@ -31,6 +31,7 @@ setuptools.setup(
     packages=setuptools.find_packages(),
     py_modules=["pymetar"],
     scripts=["bin/pymetar"],
+    data_files=[("share/man/man1", ['pymetar.1'])],
     classifiers=(
     "Programming Language :: Python :: 3",
     "License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)", 



# 1) make setup.py test command work via test_suite directive
# 2) Honour/respect user CFLAGS
# https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=233561

--- setup.py.orig	2024-01-31 07:33:33 UTC
+++ setup.py
@@ -42,7 +42,6 @@ ext_modules = [
 ext_modules = [
     Extension(
         "rencode._rencode",
-        extra_compile_args=["-O3"],
         sources=["rencode/_rencode" + source_ext],
     ),
 ]
@@ -97,4 +96,5 @@ setup(
     cmdclass={"build_ext": optional_build_ext},
     ext_modules=ext_modules,
     setup_requires=["setuptools"],
+    test_suite='tests',
 )



--- setup.py.orig	2015-10-12 21:38:11 UTC
+++ setup.py
@@ -9,7 +9,7 @@ setup(
     long_description = f.read()
 
 setup(
-    name='HoroscopeGenerator',
+    name='horoscopegenerator', 
     version='0.1.8',
 
     description='Generates horoscopes',



# -*- coding: utf-8 -*-

"""
This is an example of a locustfile that uses Locust's built in event hooks to 
track the sum of the content-length header in all successful HTTP responses
"""

from locust import HttpLocust, TaskSet, events, task, web


class MyTaskSet(TaskSet):
    @task(2)
    def index(l):
        l.client.get("/")
    
    @task(1)
    def stats(l):
        l.client.get("/stats/requests")

class WebsiteUser(HttpLocust):
    host = "http://127.0.0.1:8089"
    min_wait = 2000
    max_wait = 5000
    task_set = MyTaskSet
    

"""
We need somewhere to store the stats.

On the master node stats will contain the aggregated sum of all content-lengths,
while on the slave nodes this will be the sum of the content-lengths since the 
last stats report was sent to the master
"""
stats = {"content-length":0}

def on_request_success(request_type, name, response_time, response_length):
    """
    Event handler that get triggered on every successful request
    """
    stats["content-length"] += response_length

def on_report_to_master(client_id, data):
    """
    This event is triggered on the slave instances every time a stats report is
    to be sent to the locust master. It will allow us to add our extra content-length
    data to the dict that is being sent, and then we clear the local stats in the slave.
    """
    data["content-length"] = stats["content-length"]
    stats["content-length"] = 0

def on_slave_report(client_id, data):
    """
    This event is triggered on the master instance when a new stats report arrives
    from a slave. Here we just add the content-length to the master's aggregated
    stats dict.
    """
    stats["content-length"] += data["content-length"]

# Hook up the event listeners
events.request_success += on_request_success
events.report_to_master += on_report_to_master
events.slave_report += on_slave_report

@web.app.route("/content-length")
def total_content_length():
    """
    Add a route to the Locust web app, where we can see the total content-length
    """
    return "Total content-length recieved: %i" % stats["content-length"]



--- hid/__init__.py.orig	2024-04-11 03:39:41 UTC
+++ hid/__init__.py
@@ -7,6 +7,7 @@ library_paths = (
 
 hidapi = None
 library_paths = (
+    'libhidapi.so',
     'libhidapi-hidraw.so',
     'libhidapi-hidraw.so.0',
     'libhidapi-libusb.so',



--- buildscripts/scons.py.orig	2021-08-23 09:10:10 UTC
+++ buildscripts/scons.py
@@ -18,14 +18,14 @@ SITE_TOOLS_DIR = os.path.join(MONGODB_ROOT, 'site_scon
 
 sys.path = [SCONS_DIR, SITE_TOOLS_DIR] + sys.path
 
-# pylint: disable=C0413
-from mongo.pip_requirements import verify_requirements, MissingRequirements
-
-try:
-    verify_requirements('etc/pip/compile-requirements.txt')
-except MissingRequirements as ex:
-    print(ex)
-    sys.exit(1)
+## pylint: disable=C0413
+#from mongo.pip_requirements import verify_requirements, MissingRequirements
+#
+#try:
+#    verify_requirements('etc/pip/compile-requirements.txt')
+#except MissingRequirements as ex:
+#    print(ex)
+#    sys.exit(1)
 
 try:
     import SCons.Script



--- setup.py.orig	2021-04-05 15:27:07 UTC
+++ setup.py
@@ -11,7 +11,6 @@ def main():
     setup(  name = "CrossMap",
             version = "0.5.2",
             python_requires='>=3.5',
-            py_modules = [ 'psyco_full' ],
             packages = find_packages( 'lib' ),
             package_dir = { '': 'lib' },
             package_data = { '': ['*.ps'] },



--- NanoVNASaver/Hardware/Hardware.py.orig	2022-04-01 14:51:11 UTC
+++ NanoVNASaver/Hardware/Hardware.py
@@ -34,6 +34,7 @@ from NanoVNASaver.Hardware.NanoVNA_H4 import NanoVNA_H
 from NanoVNASaver.Hardware.NanoVNA_V2 import NanoVNA_V2
 from NanoVNASaver.Hardware.TinySA import TinySA
 from NanoVNASaver.Hardware.Serial import drain_serial, Interface
+from NanoVNASaver.Hardware.Sysctl import usb_vid_pid
 
 
 logger = logging.getLogger(__name__)
@@ -80,6 +81,11 @@ def get_interfaces() -> List[Interface]:
     for d in list_ports.comports():
         if platform.system() == 'Windows' and d.vid is None:
             d = _fix_v2_hwinfo(d)
+        if platform.system() == 'FreeBSD':
+            logger.debug("Found FreeBSD USB port %s", d.device)
+            vid_pid = usb_vid_pid(d.device)
+            d.vid = vid_pid[0]
+            d.pid = vid_pid[1]
         for t in USBDEVICETYPES:
             if d.vid != t.vid or d.pid != t.pid:
                 continue
@@ -87,14 +93,17 @@ def get_interfaces() -> List[Interface]:
                          t.name, d.vid, d.pid, d.device)
             iface = Interface('serial', t.name)
             iface.port = d.device
-            iface.open()
+            try:
+                iface.open()
+            except serial.SerialException:
+                logger.warning("Could not open serial port %s", d.device)
+                continue
             iface.comment = get_comment(iface)
             iface.close()
             interfaces.append(iface)
 
     logger.debug("Interfaces: %s", interfaces)
     return interfaces
-
 
 def get_VNA(iface: Interface) -> 'VNA':
     # serial_port.timeout = TIMEOUT



--- asrun/system.py.orig	2017-07-13 07:40:52 UTC
+++ asrun/system.py
@@ -133,10 +133,10 @@ def get_system_tmpdir():
        or os.environ.get('TEMP') or os.environ.get('TMP')
     if var:
         return var
-    if on_linux():
-        return "/tmp"
-    else:
+    if on_windows():
         return osp.join(os.environ.get("%systemroot%", "c:\\windows"), "temp")
+    else:
+        return "/tmp"
 
 
 def split_path(path):
@@ -854,6 +854,8 @@ class AsterSystem:
                     num = max([int(i) for i in l_ids]) + 1
             elif on_windows():
                 num = 1
+            else:
+                num = %%MAKE_JOBS_NUMBER%%
             self._cpuinfo_cache[what+mach+user] = num
             self._dbg("GetCpuInfo '%s' returns : %s" % (what, num))
             return num



# from https://github.com/fbergmann/libSEDML/issues/152

import libsedml

# create data set
data_set = libsedml.SedDataSet()

# set id
assert data_set.setId('obj') == 0

# check id set
assert data_set.getId() == 'obj'

# set empty name
assert data_set.setName('') == 0

# id is no longer set!
assert data_set.getId() == 'obj'

print("Test passed");



--- pyradio/ping.py.orig	2022-12-09 15:36:15 UTC
+++ pyradio/ping.py
@@ -49,7 +49,7 @@ def linux_ping(server, count=1, timeout_in_seconds=1):
             return 0 if '100%' in out[0] else 1
         else:
             r=subprocess.Popen(
-                ['ping', '-c', str(count), '-w',
+                ['ping', '-c', str(count), '-t',
                  str(timeout_in_seconds), server],
                 stderr=subprocess.DEVNULL,
                 stdout=subprocess.PIPE



--- setup.py.orig	2022-11-26 00:17:16 UTC
+++ setup.py
@@ -371,7 +371,7 @@ class build_ext(build_ext_):
         else:
             openmpflag = "-fopenmp"
             archi = platform.machine()
-            if archi in ("i386", "x86_64"):
+            if archi in ("amd64", "i386", "x86_64"):
                 compileflags = COMPILE_FLAGS + ["-march=%s" % self.march]
             else:
                 compileflags = COMPILE_FLAGS + ["-mcpu=%s" % self.march]



from locust import HttpLocust, TaskSet, task
import random

def index(l):
    l.client.get("/")

def stats(l):
    l.client.get("/stats/requests")

class UserTasks(TaskSet):
    # one can specify tasks like this
    tasks = [index, stats]
    
    # but it might be convenient to use the @task decorator
    @task
    def page404(self):
        self.client.get("/does_not_exist")
    
class WebsiteUser(HttpLocust):
    """
    Locust user class that does requests to the locust web server running on localhost
    """
    host = "http://127.0.0.1:8089"
    # Most task inter-arrival times approximate to exponential distributions
    # We will model this wait time as exponentially distributed with a mean of 1 second
    wait_function = lambda self: random.expovariate(1)*1000 # *1000 to convert to milliseconds
    task_set = UserTasks

def strictExp(min_wait,max_wait,mu=1):
    """
    Returns an exponentially distributed time strictly between two bounds.
    """
    while True:
        x = random.expovariate(mu)
        increment = (max_wait-min_wait)/(mu*6.0)
        result = min_wait + (x*increment)
        if result<max_wait:
            break
    return result

class StrictWebsiteUser(HttpLocust):
    """
    Locust user class that makes exponential requests but strictly between two bounds.
    """
    host = "http://127.0.0.1:8089"
    wait_function = lambda self: strictExp(self.min_wait, self.max_wait)*1000
    task_set = UserTasks







# add_stylesheet() deprecated on Sphinx 4.0
# https://www.sphinx-doc.org/en/master/extdev/deprecated.html
--- doc/conf.py.orig	2018-10-15 08:43:14 UTC
+++ doc/conf.py
@@ -288,4 +288,4 @@ texinfo_documents = [
 #texinfo_no_detailmenu = False
 
 def setup(app):
-    app.add_stylesheet('style.css')
+    app.add_css_file('style.css')



--- src/StreamDeck/Transport/LibUSBHIDAPI.py.orig	2024-04-08 21:05:19 UTC
+++ src/StreamDeck/Transport/LibUSBHIDAPI.py
@@ -154,6 +154,7 @@ class LibUSBHIDAPI(Transport):
                 "Windows": ["hidapi.dll", "libhidapi-0.dll", "./hidapi.dll"],
                 "Linux": ["libhidapi-libusb.so", "libhidapi-libusb.so.0"],
                 "Darwin": ["libhidapi.dylib"],
+                "FreeBSD": ["libhidapi.so"],
             }
 
             self.platform_name = platform.system()



--- barman/config.py.orig	2024-11-23 11:42:48 UTC
+++ barman/config.py
@@ -1194,15 +1194,15 @@ class Config(object):
 class Config(object):
     """This class represents the barman configuration.
 
-    Default configuration files are /etc/barman.conf,
-    /etc/barman/barman.conf
+    Default configuration files are %%PREFIX%%/etc/barman.conf,
+    %%PREFIX%%/etc/barman/barman.conf
     and ~/.barman.conf for a per-user configuration
     """
 
     CONFIG_FILES = [
         "~/.barman.conf",
-        "/etc/barman.conf",
-        "/etc/barman/barman.conf",
+        "%%PREFIX%%/etc/barman.conf",
+        "%%PREFIX%%/etc/barman/barman.conf",
     ]
 
     _QUOTE_RE = re.compile(r"""^(["'])(.*)\1$""")



--- backends/smt2/smtio.py.orig	2023-01-04 19:51:15 UTC
+++ backends/smt2/smtio.py
@@ -182,9 +182,9 @@ class SmtIo:
                 self.noincr = True
 
             if self.noincr:
-                self.popen_vargs = ['yices-smt2'] + self.solver_opts
+                self.popen_vargs = ['yices_smt2'] + self.solver_opts
             else:
-                self.popen_vargs = ['yices-smt2', '--incremental'] + self.solver_opts
+                self.popen_vargs = ['yices_smt2', '--incremental'] + self.solver_opts
             if self.timeout != 0:
                 self.popen_vargs.append('-t')
                 self.popen_vargs.append('%d' % self.timeout);



from skyfield.api import load

planets = load('de421.bsp')
earth, mars = planets['earth'], planets['mars']

ts = load.timescale()
t = ts.now()
position = earth.at(t).observe(mars)
ra, dec, distance = position.radec()

print(ra)
print(dec)
print(distance)



import time
import xmlrpclib

from locust import Locust, TaskSet, events, task


class XmlRpcClient(xmlrpclib.ServerProxy):
    """
    Simple, sample XML RPC client implementation that wraps xmlrpclib.ServerProxy and 
    fires locust events on request_success and request_failure, so that all requests 
    gets tracked in locust's statistics.
    """
    def __getattr__(self, name):
        func = xmlrpclib.ServerProxy.__getattr__(self, name)
        def wrapper(*args, **kwargs):
            start_time = time.time()
            try:
                result = func(*args, **kwargs)
            except xmlrpclib.Fault as e:
                total_time = int((time.time() - start_time) * 1000)
                events.request_failure.fire(request_type="xmlrpc", name=name, response_time=total_time, exception=e)
            else:
                total_time = int((time.time() - start_time) * 1000)
                events.request_success.fire(request_type="xmlrpc", name=name, response_time=total_time, response_length=0)
                # In this example, I've hardcoded response_length=0. If we would want the response length to be 
                # reported correctly in the statistics, we would probably need to hook in at a lower level
        
        return wrapper


class XmlRpcLocust(Locust):
    """
    This is the abstract Locust class which should be subclassed. It provides an XML-RPC client
    that can be used to make XML-RPC requests that will be tracked in Locust's statistics.
    """
    def __init__(self, *args, **kwargs):
        super(XmlRpcLocust, self).__init__(*args, **kwargs)
        self.client = XmlRpcClient(self.host)


class ApiUser(XmlRpcLocust):
    
    host = "http://127.0.0.1:8877/"
    min_wait = 100
    max_wait = 1000
    
    class task_set(TaskSet):
        @task(10)
        def get_time(self):
            self.client.get_time()
        
        @task(5)
        def get_random_number(self):
            self.client.get_random_number(0, 100)
